#!/bin/sh
# test we are root
if [ "$(id -u)" != "0" ]; then
   exit 1
fi

export CFLAGS="-mtune=generic -Os -pipe"
export CXXFLAGS="-mtune=generic -Os -pipe -fno-exceptions -fno-rtti "

P=libgnome-games-support
V=1.8.2
SRC=$P-$V
USER=`cat /etc/sysconfig/tcuser`
LIST="compiletc submitqc git meson cmake vala-dev libgee-dev gtk3-dev"
for Z in $LIST 
    do 
    su -c "tce-load -i $Z" $USER
done

cd /tmp
su -c "/usr/local/bin/wget -nc --no-check-certificate \
https://gitlab.gnome.org/GNOME/$P/-/archive/$V/$SRC.tar.bz2" $USER
tar jxvf $SRC*bz2
cd $SRC
mkdir build && cd build
meson setup --prefix=/usr/local -Dstrip=true -Ddebug=false
meson configure 
# User defined options
# debug : false
# prefix: /usr/local
# strip : true
ninja # seconds
DESTDIR=/tmp/$P ninja install
cd /tmp

# dev
#####
mkdir -p $P-dev/usr/local/lib
mv $P/usr/local/lib/pkgconfig $P-dev/usr/local/lib
mv $P/usr/local/include $P-dev/usr/local

# locale
#########
mkdir -p $P-locale/usr/local/share
mv $P/usr/local/share/locale $P-locale/usr/local/share

# main
######
mkdir -p $P/usr/local/share/doc/$P
echo 'GPL v3' > $P/usr/local/share/doc/$P/COPYING

# TCZ them
#######
LIST="$P $P-dev $P-locale "
for Z in $LIST
do
	mksquashfs $Z $Z.tcz
	md5sum $Z.tcz > $Z.tcz.md5.txt
	cd $Z
	find usr -not -type d > /tmp/$Z.tcz.list
        sed 's|usr|/usr|g' -i /tmp/$Z.tcz.list
	cd /tmp
done

ls -hal

echo 'Title:          libgnome-games-support-dev.tcz 
Description:    game for support for gnome
Version:        1.8.2
Author:         Gnome Developers
Original-site:  https://gitlab.gnome.org/GNOME/libgnome-games-support
Copying-policy: GPL v3
Size:           8.0K
Extension_by:   aus9 @linuxquestions.org
Tags:           gnome games
Comments:       - 

Change-log:     2023/07/31 v 1.8.2 on 15x
Current:        2024/07/31      ' > $P-dev.tcz.info
echo 'libgnome-games-support.tcz 
vala-dev.tcz  
libgee-dev.tcz  
gtk4-dev.tcz ' > $P-dev.tcz.dep

echo 'Title:          libgnome-games-support-locale.tcz 
Description:    language files
Version:        1.8.2
Author:         Gnome Developers
Original-site:  https://gitlab.gnome.org/GNOME/libgnome-games-support
Copying-policy: GPL v3
Size:           36K
Extension_by:   aus9 @linuxquestions.org
Tags:           gnome games
Comments:       locales 

Change-log:     2023/07/31 v 1.8.2 on 15x
Current:        2024/07/31      ' > $P-locale.tcz.info
echo 'libgnome-games-support.tcz ' > $P-locale.tcz.dep

echo 'Title:          libgnome-games-support.tcz 
Description:    game for support for gnome
Version:        1.8.2
Author:         Gnome Developers
Original-site:  https://gitlab.gnome.org/GNOME/libgnome-games-support
Copying-policy: GPL v3
Size:           32K
Extension_by:   aus9 @linuxquestions.org
Tags:           gnome games
Comments:       - 

Change-log:     2023/07/31 v 1.8.2 on 15x
Current:        2024/07/31      ' > $P.tcz.info

readelf -d $P/usr/local/lib/*.so | grep 'NEEDED' 
#[libgee-0.8.so.2] libgee
#[libgobject-2.0.so.0][libglib-2.0.so.0][libgio-2.0.so.0]glib2 -> libgee
#[libgtk-3.so.1][libgdk-3.so.0]gtk3

echo 'libgee.tcz
gtk3.tcz ' > $P.tcz.dep

submitqc --libs
rm -rf *.zsync
